==> cdktf_cdktf_provider_azurerm-9.0.3-py3-none-any.whl: package/lib/data-azurerm-web-pubsub/index.d.ts <==
/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermWebPubsubConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.65.0/docs/data-sources/web_pubsub#id DataAzurermWebPubsub#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.65.0/docs/data-sources/web_pubsub#name DataAzurermWebPubsub#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.65.0/docs/data-sources/web_pubsub#resource_group_name DataAzurermWebPubsub#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.65.0/docs/data-sources/web_pubsub#timeouts DataAzurermWebPubsub#timeouts}
    */
    readonly timeouts?: DataAzurermWebPubsubTimeouts;
}
export interface DataAzurermWebPubsubTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.65.0/docs/data-sources/web_pubsub#read DataAzurermWebPubsub#read}
    */
    readonly read?: string;
}
export declare function dataAzurermWebPubsubTimeoutsToTerraform(struct?: DataAzurermWebPubsubTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermWebPubsubTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataAzurermWebPubsubTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataAzurermWebPubsubTimeouts | cdktf.IResolvable | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.65.0/docs/data-sources/web_pubsub azurerm_web_pubsub}
*/
export declare class DataAzurermWebPubsub extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "azurerm_web_pubsub";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.65.0/docs/data-sources/web_pubsub azurerm_web_pubsub} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermWebPubsubConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermWebPubsubConfig);
    get aadAuthEnabled(): cdktf.IResolvable;
    get capacity(): number;
    get externalIp(): string;
    get hostname(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get localAuthEnabled(): cdktf.IResolvable;
    get location(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get primaryAccessKey(): string;
    get primaryConnectionString(): string;
    get publicNetworkAccessEnabled(): cdktf.IResolvable;
    get publicPort(): number;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    get secondaryAccessKey(): string;
    get secondaryConnectionString(): string;
    get serverPort(): number;
    get sku(): string;
    private _tags;
    get tags(): cdktf.StringMap;
    get tlsClientCertEnabled(): cdktf.IResolvable;
    get version(): string;
    private _timeouts;
    get timeouts(): DataAzurermWebPubsubTimeoutsOutputReference;
    putTimeouts(value: DataAzurermWebPubsubTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataAzurermWebPubsubTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-11.0.1-py3-none-any.whl: package/lib/data-azurerm-web-pubsub/index.d.ts <==
/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermWebPubsubConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.77.0/docs/data-sources/web_pubsub#id DataAzurermWebPubsub#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.77.0/docs/data-sources/web_pubsub#name DataAzurermWebPubsub#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.77.0/docs/data-sources/web_pubsub#resource_group_name DataAzurermWebPubsub#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.77.0/docs/data-sources/web_pubsub#timeouts DataAzurermWebPubsub#timeouts}
    */
    readonly timeouts?: DataAzurermWebPubsubTimeouts;
}
export interface DataAzurermWebPubsubTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.77.0/docs/data-sources/web_pubsub#read DataAzurermWebPubsub#read}
    */
    readonly read?: string;
}
export declare function dataAzurermWebPubsubTimeoutsToTerraform(struct?: DataAzurermWebPubsubTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermWebPubsubTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataAzurermWebPubsubTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataAzurermWebPubsubTimeouts | cdktf.IResolvable | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.77.0/docs/data-sources/web_pubsub azurerm_web_pubsub}
*/
export declare class DataAzurermWebPubsub extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "azurerm_web_pubsub";
    /**
    * Generates CDKTF code for importing a DataAzurermWebPubsub resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataAzurermWebPubsub to import
    * @param importFromId The id of the existing DataAzurermWebPubsub that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.77.0/docs/data-sources/web_pubsub#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataAzurermWebPubsub to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.77.0/docs/data-sources/web_pubsub azurerm_web_pubsub} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermWebPubsubConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermWebPubsubConfig);
    get aadAuthEnabled(): cdktf.IResolvable;
    get capacity(): number;
    get externalIp(): string;
    get hostname(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get localAuthEnabled(): cdktf.IResolvable;
    get location(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get primaryAccessKey(): string;
    get primaryConnectionString(): string;
    get publicNetworkAccessEnabled(): cdktf.IResolvable;
    get publicPort(): number;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    get secondaryAccessKey(): string;
    get secondaryConnectionString(): string;
    get serverPort(): number;
    get sku(): string;
    private _tags;
    get tags(): cdktf.StringMap;
    get tlsClientCertEnabled(): cdktf.IResolvable;
    get version(): string;
    private _timeouts;
    get timeouts(): DataAzurermWebPubsubTimeoutsOutputReference;
    putTimeouts(value: DataAzurermWebPubsubTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataAzurermWebPubsubTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
